import java.util.*;

/**
 * Klasse ASCII_Art
 * ----------------
 * Steuer- unc Control-Klasse des ASCII-Art-Zeichenprogramms  "ASCII + Art".
 * 
 * Autor: Dr. Hanno Schauer, Mons-Tabor-Gymnasium Montabaur
 * Lizenz: Creative Commens BY 4.0 (http://creativecommons.org/licenses/by/4.0/legalcode)
 */

public class ASCII_Art
{
    // Klassenvariablen
    protected static Scanner input = new Scanner(System.in); // Neues 'Scanner'-Objekt erzeugen und der Variable 'input' zuweisen

    /**
     * main()
     */
    public static void main(String[] args){
        // Variablendeklaration
        String style = "-";
        boolean eingabeKorrekt = false;
        
        // Begrüßung 
        System.out.println ();
        asciiPrint ("ASCII + Art", 'f');
        
        // Eingabe
        System.out.println ();
        System.out.println ();
        System.out.println ();
        System.out.println ("***************  W I L L K O M M E N !  ***************");
        System.out.println ();
        System.out.println ();
        System.out.print ("Ihr Text: ");
        String txt = input.nextLine();
        
        do {
            System.out.println ();
            System.out.println ("Mögliche Text-Stile:" );
            System.out.println ("       [n] für normal" );
            System.out.println ("       [k] für kursiv" );
            System.out.println ("       [f] für fett" );
            System.out.println ("       [x] für fett + kursiv" );
            
            System.out.println ();
            System.out.print("Ihr Stil:" );
            style = input.nextLine();

            eingabeKorrekt = ((style == "k") || (style.equals("n")) || (style == "f") || (style == "x"));
        } while (!eingabeKorrekt);
        System.out.println ();
        System.out.println ("********************************************");
        System.out.println ("Here You Go ...");
        System.out.println ();
        
        // Aufruf von Verarbeitung und Ausgabe
        asciiPrint (txt, style.charAt(0));
        
        // Finalisierung
        System.out.println ();
    }
    
    /**
     * asciiPrint()
     * ------------
     * Gibt den gewählten 'text' im Stil 'style' am Bildschirm aus.
     */
    static void asciiPrint(String text, char style) {
        // Variablendeklaration
        boolean italic = false;;
        boolean bold = false;
        
        // 'style' in lokale Variablen übersetzen 
        switch (style) {
            case 'n' : italic = false;
                       bold = false;
                       break;
            case 'k' : italic = true;
                       bold = false;   
            case 'f' : italic = false;
                       bold = true;
            case 'x' : italic = true;
                       bold = true;
            default : System.out.println("FEHLER: Nicht unterstützter 'style' in Methode 'ASCII_Art.main()'");
        }

        // Verarbeitung: Zeile für Zeile (line) den Bild-Anbeil (lineFeed) der Buchstaben ausgeben.
        for (int line = 1; line <= 11; line++){
            if (italic) 
                for (int i = 0; i < 11-line; i++) System.out.print(" "); // Schrift-Versatz bei kursiver Schrift ('italic')
            for (int index = 0; index < text.length(); index++){  // Eine Zeile generieren
                String lineFeed = BuchstabenZeile(text.charAt(index), line);
                if (bold) lineFeed = lineFeed.toUpperCase();  // Fettdruck durch Großbuchstaben (z.B. 'X' statt 'x') nachahmen
                System.out.print(lineFeed); 
                System.out.print("  "); // Leerzeichen zwischen zwei Buchstaben
            }
            System.out.println(); // Zeilenumbruch
        }
    }
    
    /**
     * BuchstabenZeile()
     * -----------------
     * Gibt von der ASCII-Art-Darstellung des Buchstabens 'c' jeweils die Zeile Nummer 'line' zurück.
     */
    static String BuchstabenZeile (char c, int line){
        // Initialisierung
        char bigC = Character.toUpperCase(c);  // Umwandlung aller Zeichen in Großbuchstaben
        String lineFeed = "";
        
        // Verarbeitung: Aufruf der jeweiligen Buchstabenmethode in der Klasse 'ABC'
        switch(bigC){
            // +++ Verfügbare Buchstaben +++
            case 'A': return ABC.A(line);
            case 'B': return ABC.B(line); 
            case 'C': return ABC.C(line); 
            // case 'D': return ABC.D(line); 
            case 'E': return ABC.E(line); 
            case 'F': return ABC.F(line);
            case 'G': return ABC.G(line); 
            case 'H': return ABC.H(line); 
            case 'I': return ABC.I(line); 
            //case 'J': return ABC.J(line); 
            //case 'K': return ABC.K(line); 
            case 'L': return ABC.L(line); 
            //case 'M': return ABC.M(line); 
            //case 'N': return ABC.N(line); 
            case 'O': return ABC.O(line); 
            case 'P': return ABC.P(line); 
            //case 'Q': return ABC.Q(line); 
            case 'R': return ABC.R(line); 
            case 'S': return ABC.S(line); 
            case 'T': return ABC.T(line); 
            case 'U': return ABC.U(line); 
            //case 'V': return ABC.V(line); 
            //case 'W': return ABC.W(line); 
            case 'X': return ABC.X(line); 
            case 'Y': return ABC.Y(line); 
            //case 'Z': return ABC.Z(line); 
            
            // +++ Verfügbare Sonderzeichen +++
            case '+': return ABC.plus(line);
            case ' ': return ABC.leerzeichen(line);
            case '!': return ABC.rufzeichen(line);
            
            // +++ Fehlermeldung, falls (noch) nicht implementiertes Zeichen abgerufen wird +++
            default : System.out.println("FEHLER: Nicht unterstütztes Zeichen '" + Character.toUpperCase(c) + "' in Methode 'ASCII_Art.BuchstabenZeile'");
                      return ""; 
        }
    }
}

